Release history
===============

.. currentmodule:: pytest_trio

.. towncrier release notes start

Pytest_Trio 0.2.0 (2017-12-15)
------------------------------

Features
~~~~~~~~

- Heavy improvements, add async yield fixture, fix bugs, add tests etc. (`#17
  <https://github.com/python-trio/pytest-trio/issues/17>`__)


Deprecations and Removals
~~~~~~~~~~~~~~~~~~~~~~~~~

- Remove unused_tcp_port{,_factory} fixtures (`#15
  <https://github.com/python-trio/pytest-trio/issues/15>`__)


Pytest_Trio 0.1.1 (2017-12-08)
------------------------------

Disable intersphinx for trio (cause crash in CI for the moment due to 404
in readthedoc).


Pytest_Trio 0.1.0 (2017-12-08)
------------------------------

Initial release.
